# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from aihub.models.modification_object_modifications_inner import ModificationObjectModificationsInner
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ModificationObject(BaseModel):
    """
    ModificationObject
    """ # noqa: E501
    timestamp: Optional[StrictStr] = Field(default=None, description="Datetime string of the edit history event.")
    user_id: Optional[StrictStr] = Field(default=None, description="User ID of the user who made the edit.")
    modifications: Optional[List[ModificationObjectModificationsInner]] = Field(default=None, description="List of modifications made in this single edit history event.")
    __properties: ClassVar[List[str]] = ["timestamp", "user_id", "modifications"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ModificationObject from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in modifications (list)
        _items = []
        if self.modifications:
            for _item in self.modifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['modifications'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ModificationObject from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "timestamp": obj.get("timestamp"),
            "user_id": obj.get("user_id"),
            "modifications": [ModificationObjectModificationsInner.from_dict(_item) for _item in obj.get("modifications")] if obj.get("modifications") is not None else None
        })
        return _obj


